==> owncloud-news_5.3.8%2Bdfsg.orig.tar.gz: news-5.3.8/l10n/id.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "Feed berisi XML yang tidak sah",
"Could not find a feed" => "Tidak dapat menemukan feed",
"Detected feed format is not supported" => "Ditemukan format feed yang tidak didukung",
"SSL Certificate is invalid" => "Sertifikat SSL tidak sah",
"Website not found" => "Situs web tidak ditemukan",
"More redirects than allowed, aborting" => "Pengalihan melebihi dari yang diizinkan, membatalkan",
"Bigger than maximum allowed size" => "Lebih besar dari ukuran yang diizinkan",
"Request timed out" => "Permintaan kehabisan waktu",
"Request failed, network connection unavailable!" => "Permintaan gagal, koneksi jaringan tidak tersedia!",
"Request unauthorized. Are you logged in?" => "Permintaan tidak sah. Apakah Anda sudah masuk?",
"Request forbidden. Are you an admin?" => "Permintaan dilarang. Apakah Anda admin?",
"Token expired or app not enabled! Reload the page!" => "Token telah kadaluarsa atau aplikasi tidak diaktifkan! Muat ulang halaman!",
"Internal server error! Please check your " => "Kesalahan internal server! Mohon diperiksa",
"Request failed, ownCloud is in currently " => "Permintaan gagal, ownCloud saat ini ",
"Can not add feed: Exists already" => "Tidak dapat menambah feed: Sudah ada",
"Articles without feed" => "Artikel tanpa feed",
"Can not add folder: Exists already" => "Tidak dapat menambah folder: Sudah ada",
"Use ownCloud cron for updates" => "Gunakan cron ownCloud untuk pembaruan",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Nonaktifkan ini jika ANda menjalankan updater kostum seperti updater Python didalam aplikasi",
"Purge interval" => "Singkirkan interval",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Jumlah detik minimum setelah feed dan folder yang terhapus akan dihapus dari basis data; nilai di bawah 60 detik akan diabaikan",
"Maximum read count per feed" => "Jumlah baca maksimum per feed",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Tentukan jumlah artikel maksimal yang dapat dibaca per feed yang tidak ingin dihapus oleh tugas penghapusan; jika artikel lama muncul kembali setelah dibaca, naikkan nilai ini; nilai negatif seperti -1 akan benar-benar mematikan fitur ini.",
"Maximum redirects" => "Pengalihan maksimum",
"How many redirects the feed fetcher should follow" => "Berapa banyak pengalihan yang pengambil feed harus ikuti",
"Maximum feed page size" => "Ukuran halaman feed maksimal",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Ukuran feed maksimal dalam byte. Jika halaman RSS/Atom lebih besar dari nilai ini, pembaruan akan dibatalkan",
"Feed fetcher timeout" => "Pengambil feed kehabisan waktu",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Jumlah detik maksimum untuk menunggu feed RSS atau Atom dimuat; jika memakan waktu lebih lama, pembaruan akan dibatalkan",
"Explore Service URL" => "URL Layanan Jelajah",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Jika diberikan, URL layanan ini akan dikuerikan untuk menampilkan feed dalam sesi feed jelajah. Untuk kembali ke build dalam layanan jelajah, biarkan bernilai kosong",
"Saved" => "Disimpan",
"Download" => "Unduh",
"Close" => "Tutup",
"Ajax cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Mode cron ajax terdeteksi! Feed ANda tidak akan terunggah dengan benar. Direkomendasikan untuk menggunakan cron sistem operasi atau pengupdate kostum.",
"How to set up the operating system cron" => "Bagaimana cara menyetel cron sistem operasi",
"How to set up a custom updater (faster and no possible deadlock) " => "Bagaimana cara menyetel pengupdate kostum (lebih cepat dan tidak mungkin mogok)",
"Subscribe" => "Berlangganan",
"Refresh" => "Segarkan",
"No articles available" => "Tidak ada artikel yang tersedia",
"No unread articles available" => "Tidak ada artikel yang belum dibaca",
"Open website" => "Buka situs web",
"Star article" => "Bintangi artikel",
"Unstar article" => "Hapus bintang artikel",
"Keep article unread" => "Tandai artikel belum dibaca",
"Remove keep article unread" => "Hapus tanda artikel belum dibaca",
"by" => "oleh",
"from" => "dari",
"Play audio" => "Putar audio",
"Download video" => "Unduh video",
"Download audio" => "Unduh audio",
"Keyboard shortcut" => "Pintasan keyboard",
"Description" => "Keterangan",
"right" => "kanan",
"Jump to next article" => "Lompat ke artikel berikutnya",
"left" => "kiri",
"Jump to previous article" => "Lompat ke artikel sebelumnya",
"Toggle star article" => "Tombol alih bintangi artikel",
"Star article and jump to next one" => "Bintangi artikel dan lompat ke berikutnya",
"Toggle keep current article unread" => "Tombol alih tandai artikel saat ini belum dibaca",
"Open article in new tab" => "Buka artikel di tab baru",
"Toggle expand article in compact view" => "Tombol alih perluas tulisan dalam tampilan kompak",
"Load next feed" => "Muat feed berikutnya",
"Load previous feed" => "Muat feed sebelumnya",
"Load next folder" => "Muat folder berikutnya",
"Load previous folder" => "Muat folder sebelumnya",
"Scroll to active navigation entry" => "Gulir ke entri navigasi aktif",
"Focus search field" => "Kolom pencarian terfokus",
"Mark current article's feed/folder read" => "Tandai feed/folder artikel saat ini telah dibaca",
"Web address" => "Alamat web",
"Feed exists already!" => "Feed sudah ada!",
"Folder" => "Folder",
"No folder" => "Tidak ada folder",
"New folder" => "Folder baru",
"Folder name" => "Nama folder",
"Go back" => "Kembali",
"Folder exists already!" => "Folder sudah ada!",
"New Folder" => "Folder Baru",
"Create" => "Buat",
"Explore" => "Jelajah",
"Deleted feed" => "Feed yang dihapus",
"Undo delete feed" => "Batalkan hapus feed",
"Rename" => "Ubah nama",
"Menu" => "Menu",
"No feed ordering" => "Tidak ada feed yang pesan",
"Reversed feed ordering" => "Pemesanan feed terbalik",
"Normal feed ordering" => "Pemesanan feed normal",
"Rename feed" => "Ubah nama feed",
"Delete feed" => "Hapus feed",
"Mark all articles read" => "Tandai semua artikel sudah dibaca",
"Dismiss" => "Buang",
"Collapse" => "Tutup",
"Deleted folder" => "Folder yang dihapus",
"Undo delete folder" => "Batalkan hapus folder",
"Rename folder" => "Ubah nama folder",
"Delete folder" => "Hapus folder",
"Starred" => "Dibintangi",
"Unread articles" => "Artikel belum dibaca",
"All articles" => "Semua artikel",
"Settings" => "Pengaturan",
"Keyboard shortcuts" => "Pintasan keyboard",
"Disable mark read through scrolling" => "Menonaktifkan tandai baca melalui pengguliran",
"Compact view" => "Tampilan kompak",
"Expand articles on key navigation" => "Perluas artikel di tombol navigasi",
"Show all articles" => "Tampilkan semua artikel",
"Reverse ordering (oldest on top)" => "Pengurutan terbalik (yang lama diatas)",
"Subscriptions (OPML)" => "Berlangganan (OPML)",
"Import" => "Impor",
"Export" => "Ekspor",
"Error when importing: file does not contain valid OPML" => "Terjadi kesalahan saat mengimpor: berkas tidak berisi OPML yang sah",
"Unread/Starred Articles" => "Artikel dibintangi/belum dibaca",
"Error when importing: file does not contain valid JSON" => "Terjadi kesalahan saat mengimor: berkas tidak berisi JSON yang sah"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";

==> owncloud-news_7.0.1%2Bdfsg.orig.tar.gz: news-7.0.1/l10n/id.php <==
<?php
$TRANSLATIONS = array(
"Feed contains invalid XML" => "Feed berisi XML yang tidak sah",
"Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" => "Feed tidak ditemukan: bisa karena website tidak menyediakan feed atau akses diblokir. Untuk menyingkirkan pemblokiran, cobalah dengan mengunduh feed pada server Anda dengan baris perintah menggunakan curl: curl http://the-feed.tld",
"Detected feed format is not supported" => "Ditemukan format feed yang tidak didukung",
"SSL Certificate is invalid" => "Sertifikat SSL tidak sah",
"Website not found" => "Situs web tidak ditemukan",
"More redirects than allowed, aborting" => "Pengalihan melebihi dari yang diizinkan, membatalkan",
"Bigger than maximum allowed size" => "Lebih besar dari ukuran yang diizinkan",
"Request timed out" => "Permintaan kehabisan waktu",
"Request failed, network connection unavailable!" => "Permintaan gagal, koneksi jaringan tidak tersedia!",
"Request unauthorized. Are you logged in?" => "Permintaan tidak sah. Apakah Anda sudah masuk?",
"Request forbidden. Are you an admin?" => "Permintaan dilarang. Apakah Anda admin?",
"Token expired or app not enabled! Reload the page!" => "Token telah kadaluarsa atau aplikasi tidak diaktifkan! Muat ulang halaman!",
"Internal server error! Please check your " => "Kesalahan internal server! Mohon diperiksa",
"Request failed, ownCloud is in currently " => "Permintaan gagal, ownCloud saat ini ",
"Can not add feed: Exists already" => "Tidak dapat menambah feed: Sudah ada",
"Articles without feed" => "Artikel tanpa feed",
"Can not add folder: Exists already" => "Tidak dapat menambah folder: Sudah ada",
"Use ownCloud cron for updates" => "Gunakan cron ownCloud untuk pembaruan",
"Disable this if you run a custom updater such as the Python updater included in the app" => "Nonaktifkan ini jika Anda menjalankan updater kostum seperti updater Python didalam aplikasi",
"Purge interval" => "Singkirkan interval",
"Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" => "Jumlah detik minimum setelah feed dan folder yang terhapus akan dihapus dari basis data; nilai di bawah 60 detik akan diabaikan",
"Maximum read count per feed" => "Jumlah baca maksimum per feed",
"Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" => "Tentukan jumlah artikel maksimal yang dapat dibaca per feed yang tidak ingin dihapus oleh tugas penghapusan; jika artikel lama muncul kembali setelah dibaca, naikkan nilai ini; nilai negatif seperti -1 akan benar-benar mematikan fitur ini.",
"Maximum redirects" => "Pengalihan maksimum",
"How many redirects the feed fetcher should follow" => "Berapa banyak pengalihan yang pengambil feed harus ikuti",
"Maximum feed page size" => "Ukuran halaman feed maksimal",
"Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" => "Ukuran feed maksimal dalam byte. Jika halaman RSS/Atom lebih besar dari nilai ini, pembaruan akan dibatalkan",
"Feed fetcher timeout" => "Pengambil feed kehabisan waktu",
"Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" => "Jumlah detik maksimum untuk menunggu feed RSS atau Atom dimuat; jika memakan waktu lebih lama, pembaruan akan dibatalkan",
"Explore Service URL" => "URL Layanan Jelajah",
"If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" => "Jika diberikan, URL layanan ini akan dikuerikan untuk menampilkan feed dalam sesi feed jelajah. Untuk kembali ke build dalam layanan jelajah, biarkan bernilai kosong",
"Saved" => "Disimpan",
"Download" => "Unduh",
"Close" => "Tutup",
"Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." => "Mode cron ajax atau webcron terdeteksi! Feed Anda tidak akan dapat diperbarui dengan benar. Disarankan untuk menggunakan cron sistem operasi atau menggunakan updater kostum.",
"How to set up the operating system cron" => "Bagaimana cara menyetel cron sistem operasi",
"How to set up a custom updater (faster and no possible deadlock) " => "Bagaimana cara menyetel pengupdate kostum (lebih cepat dan tidak mungkin mogok)",
"Subscribe" => "Berlangganan",
"Refresh" => "Segarkan",
"No articles available" => "Tidak ada artikel yang tersedia",
"No unread articles available" => "Tidak ada artikel yang belum dibaca",
"Open website" => "Buka situs web",
"Star article" => "Bintangi artikel",
"Unstar article" => "Hapus bintang artikel",
"Keep article unread" => "Tandai artikel belum dibaca",
"Remove keep article unread" => "Hapus tanda artikel belum dibaca",
"by" => "oleh",
"from" => "dari",
"Play audio" => "Putar audio",
"Download video" => "Unduh video",
"Download audio" => "Unduh audio",
"Keyboard shortcut" => "Pintasan keyboard",
"Description" => "Keterangan",
"right" => "kanan",
"Jump to next article" => "Lompat ke artikel berikutnya",
"left" => "kiri",
"Jump to previous article" => "Lompat ke artikel sebelumnya",
"Toggle star article" => "Tombol alih bintangi artikel",
"Star article and jump to next one" => "Bintangi artikel dan lompat ke berikutnya",
"Toggle keep current article unread" => "Tombol alih tandai artikel saat ini belum dibaca",
"Open article in new tab" => "Buka artikel di tab baru",
"Toggle expand article in compact view" => "Tombol alih perluas tulisan dalam tampilan kompak",
"Load next feed" => "Muat feed berikutnya",
"Load previous feed" => "Muat feed sebelumnya",
"Load next folder" => "Muat folder berikutnya",
"Load previous folder" => "Muat folder sebelumnya",
"Scroll to active navigation entry" => "Gulir ke entri navigasi aktif",
"Focus search field" => "Kolom pencarian terfokus",
"Mark current article's feed/folder read" => "Tandai feed/folder artikel saat ini telah dibaca",
"Web address" => "Alamat web",
"Feed exists already!" => "Feed sudah ada!",
"Folder" => "Folder",
"No folder" => "Tidak ada folder",
"New folder" => "Folder baru",
"Folder name" => "Nama folder",
"Go back" => "Kembali",
"Folder exists already!" => "Folder sudah ada!",
"New Folder" => "Folder Baru",
"Create" => "Buat",
"Explore" => "Jelajah",
"Deleted feed" => "Feed yang dihapus",
"Undo delete feed" => "Batalkan hapus feed",
"Rename" => "Ubah nama",
"Menu" => "Menu",
"Unpin feed from the top" => "Lepas feed dari posisi teratas",
"Pin feed to the top" => "Pasang feed pada posisi teratas",
"No feed ordering" => "Tidak ada feed yang pesan",
"Reversed feed ordering" => "Pemesanan feed terbalik",
"Normal feed ordering" => "Pemesanan feed normal",
"Enable full text feed fetching" => "Aktifkan pengambil feed teks penuh",
"Disable full text feed fetching" => "Nonaktifkan pengambil feed teks penuh",
"Rename feed" => "Ubah nama feed",
"Delete feed" => "Hapus feed",
"Mark all articles read" => "Tandai semua artikel sudah dibaca",
"Dismiss" => "Buang",
"Collapse" => "Tutup",
"Deleted folder" => "Folder yang dihapus",
"Undo delete folder" => "Batalkan hapus folder",
"Rename folder" => "Ubah nama folder",
"Delete folder" => "Hapus folder",
"Starred" => "Dibintangi",
"Unread articles" => "Artikel belum dibaca",
"All articles" => "Semua artikel",
"Settings" => "Pengaturan",
"Keyboard shortcuts" => "Pintasan keyboard",
"Disable mark read through scrolling" => "Menonaktifkan tandai baca melalui pengguliran",
"Compact view" => "Tampilan kompak",
"Expand articles on key navigation" => "Perluas artikel di tombol navigasi",
"Show all articles" => "Tampilkan semua artikel",
"Reverse ordering (oldest on top)" => "Pengurutan terbalik (yang lama diatas)",
"Subscriptions (OPML)" => "Berlangganan (OPML)",
"Import" => "Impor",
"Export" => "Ekspor",
"Error when importing: file does not contain valid OPML" => "Terjadi kesalahan saat mengimpor: berkas tidak berisi OPML yang sah",
"Unread/Starred Articles" => "Artikel dibintangi/belum dibaca",
"Error when importing: file does not contain valid JSON" => "Terjadi kesalahan saat mengimor: berkas tidak berisi JSON yang sah"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
